Since the flask has no strict project architecture, <br>
 it is easy for beginners to get confused when creating an application.<br>
 This library was created to help everyone who wants to create a small application.<br>
 
 ## Quick start
 ### Install:
 pip install Flask-DJ
 ### Start app:
 ```shell script
 startapp {your_app_name}
```
<br>
 
 For those who didn't work out:
 ```python
from Flask_DJ import start
from os import getcwd

yur_app_name = 'app'
start(yur_app_name, getcwd())
```
 ### New app:
 
   ```shell script
 python manage.py starapp {app_name}
```

### Start server:

```shell script
 python manage.py runserver
```
